@@ -1,10 +1,9 @@
 ;;; .emacs --- sample of ~/.emacs for MHC  -*-mode: emacs-lisp-*-
 
-(when (and (featurep 'mule) (locate-library "mhc"))
-  (if (fboundp 'mhc-select-mailer-package)
-      (mhc-select-mailer-package 'mua))
+(when (locate-library "mhc")
   (setq mhc-use-wide-scope 14)
   (setq mhc-file-line-status-strings '(" Mhc" . " MHC"))
+  (global-set-key "\C-cI" 'mhc-import)
   (eval-after-load "mhc-draft"
     (quote
      (progn
